@@ -71,9 +71,8 @@ public Q_SLOTS:
     void updateView() override;
     void updateConfig() override;
     void showDates(const QDate &start, const QDate &end, const QDate &preferredMonth = QDate()) override;
-    void showIncidences(const Akonadi::Item::List &incidenceList, const QDate &date) override;
+    void showIncidences(const Akonadi::Item::List &incidences, const QDate &date) override;
 
-    void changeIncidenceDisplayAdded(const Akonadi::Item &incidence);
     void changeIncidenceDisplay(const Akonadi::Item &incidence, Akonadi::IncidenceChanger::ChangeType) override;
 
     void clearSelection() override;
